#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    This module is a free SDL editor.
    It allows to graphically design state machines, using a formal, well-
    defined language, and generate Ada code from the models.
"""


from opengeode import opengeode, __version__
